from django import forms
from feedback.tasks import send_feedback_email_task


class FeedbackForm(forms.Form):
    email = forms.EmailField(label="Email Address")
    message = forms.CharField(
        label="Message", widget=forms.Textarea(attrs={'rows': 5}))
    honeypot = forms.CharField(widget=forms.HiddenInput(), required=False)

    def send_email(self):
        # try to trick spammers by checking whether the honeypot field is
        # filled in; not super complicated/effective but it works
        if self.cleaned_data['honeypot']:
            return False
        send_feedback_email_task.delay(
            self.cleaned_data['email'], self.cleaned_data['message'])



from .settings import *

DATABASES = {
    'default': {
        'ENGINE': 'django.db.backends.sqlite3',
        'NAME': ':memory:'
    }
}

EMAIL_BACKEND = 'django.core.mail.backends.locmem.EmailBackend'



import json
import requests

from photos.models import Photo
from photos import settings as photo_settings


def get_latest_flickr_image():
    """
    Grabs the latest image from the flick public image feed
    """
    url = photo_settings.FLICKR_JSON_FEED_URL
    r = requests.get(url)
    page_content = r.text
    # It turns out Flickr escapes single quotes (')
    # and apparently this isn't allowed and makes the JSON invalid.
    # we use String.replace to get around this
    probably_json = page_content.replace("\\'", "'")
    # now we load the json
    feed = json.loads(probably_json)
    images = feed['items']
    return images[0]


def save_latest_flickr_image():
    """
    We get the lastest image and save it to our Photo Model in the Database
    """
    flickr_image = get_latest_flickr_image()
    # lets make sure we don't save the same image more than once
    # we are assuming each Flickr image has a unique Link
    if not Photo.objects.filter(link=flickr_image['link']).exists():
        photo = Photo(
            title=flickr_image['title'],
            link=flickr_image['link'],
            image_url=flickr_image['media']['m'],
            description=flickr_image['description']
        )
        photo.save()



from rest_framework import serializers
from snippets.models import Snippet, LANGUAGE_CHOICES, STYLE_CHOICES
from django.contrib.auth.models import User


class SnippetSerializer(serializers.ModelSerializer):
    owner = serializers.ReadOnlyField(source="owner.username")

    class Meta:
        model = Snippet
        fields = ("id", "title", "code", "linenos", "language", "style", "owner")


class UserSerializer(serializers.ModelSerializer):
    snippets = serializers.PrimaryKeyRelatedField(
        many=True, queryset=Snippet.objects.all()
    )

    class Meta:
        model = User
        fields = ("id", "username", "snippets")



from django.shortcuts import render
from django.http import HttpResponse
from hello.forms import ProjectForm
from hello.models import Project


# Create your views here.


def hello_world(request, *args, **kwargs):
    # return HttpResponse("<h1>hello world</h1>")
    return render(request, "hello_world.html", {})

def project_views(request):
    context = {}
    context["objects"] = Project.objects.all()
    return render(request, "project/project.html", context)


def project_create_view(request):
    form = ProjectForm(request.POST or None)
    if form.is_valid():
        form.save()
        form = ProjectForm()
    context = {"form": form}
    return render(request, "project/project_create.html", context)



"""curtisproject URL Configuration

The `urlpatterns` list routes URLs to views. For more information please see:
    https://docs.djangoproject.com/en/2.2/topics/http/urls/
Examples:
Function views
    1. Add an import:  from my_app import views
    2. Add a URL to urlpatterns:  path('', views.home, name='home')
Class-based views
    1. Add an import:  from other_app.views import Home
    2. Add a URL to urlpatterns:  path('', Home.as_view(), name='home')
Including another URLconf
    1. Import the include() function: from django.urls import include, path
    2. Add a URL to urlpatterns:  path('blog/', include('blog.urls'))
"""
from django.contrib import admin
from django.urls import path
from django.urls import include
from django.conf.urls import url
from feedback.views import FeedbackView
from hello.views import hello_world, project_views, project_create_view
from photos.views import PhotoView
from django.views.generic import TemplateView
from .views import login, sample_api
def trigger_error(request):
    division_by_z


urlpatterns = [
    path("admin/", admin.site.urls),
    url(r'^photos$', PhotoView.as_view(), name="photos"),
    path("", hello_world, name="home"),
    path("project/", project_views, name="project"),
    path("create/", project_create_view, name="create"),
    path('', include('django_prometheus.urls')),
    url(r'^feedback/$', FeedbackView.as_view(), name="feedback"),
    path('', include('snippets.urls')),
    path('api-auth/', include('rest_framework.urls')),
    path('api/login', login),
    path('api/sampleapi', sample_api),
    path('accounts/', include('allauth.urls')),
    path('', TemplateView.as_view(template_name='login/index.html')),
    path('sentry-debug/', trigger_error),
     ]



# Generated by Django 2.2.2 on 2019-06-11 13:14

from django.conf import settings
from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    initial = True

    dependencies = [migrations.swappable_dependency(settings.AUTH_USER_MODEL)]

    operations = [
        migrations.CreateModel(
            name="Snippet",
            fields=[
                (
                    "id",
                    models.AutoField(
                        auto_created=True,
                        primary_key=True,
                        serialize=False,
                        verbose_name="ID",
                    ),
                ),
                ("created", models.DateTimeField(auto_now_add=True)),
                ("title", models.CharField(blank=True, default="", max_length=100)),
                ("code", models.TextField()),
                ("linenos", models.BooleanField(default=False)),
                (
                    "language",
                    models.CharField(
                        choices=[
                            ("abap", "ABAP"),
                            ("abnf", "ABNF"),
                            ("ada", "Ada"),
                            ("adl", "ADL"),
                            ("agda", "Agda"),
                            ("aheui", "Aheui"),
                            ("ahk", "autohotkey"),
                            ("alloy", "Alloy"),
                            ("ampl", "Ampl"),
                            ("antlr", "ANTLR"),
                            ("antlr-as", "ANTLR With ActionScript Target"),
                            ("antlr-cpp", "ANTLR With CPP Target"),
                            ("antlr-csharp", "ANTLR With C# Target"),
                            ("antlr-java", "ANTLR With Java Target"),
                            ("antlr-objc", "ANTLR With ObjectiveC Target"),
                            ("antlr-perl", "ANTLR With Perl Target"),
                            ("antlr-python", "ANTLR With Python Target"),
                            ("antlr-ruby", "ANTLR With Ruby Target"),
                            ("apacheconf", "ApacheConf"),
                            ("apl", "APL"),
                            ("applescript", "AppleScript"),
                            ("arduino", "Arduino"),
                            ("as", "ActionScript"),
                            ("as3", "ActionScript 3"),
                            ("aspectj", "AspectJ"),
                            ("aspx-cs", "aspx-cs"),
                            ("aspx-vb", "aspx-vb"),
                            ("asy", "Asymptote"),
                            ("at", "AmbientTalk"),
                            ("augeas", "Augeas"),
                            ("autoit", "AutoIt"),
                            ("awk", "Awk"),
                            ("basemake", "Base Makefile"),
                            ("bash", "Bash"),
                            ("bat", "Batchfile"),
                            ("bbcbasic", "BBC Basic"),
                            ("bbcode", "BBCode"),
                            ("bc", "BC"),
                            ("befunge", "Befunge"),
                            ("bib", "BibTeX"),
                            ("blitzbasic", "BlitzBasic"),
                            ("blitzmax", "BlitzMax"),
                            ("bnf", "BNF"),
                            ("boa", "Boa"),
                            ("boo", "Boo"),
                            ("boogie", "Boogie"),
                            ("brainfuck", "Brainfuck"),
                            ("bro", "Bro"),
                            ("bst", "BST"),
                            ("bugs", "BUGS"),
                            ("c", "C"),
                            ("c-objdump", "c-objdump"),
                            ("ca65", "ca65 assembler"),
                            ("cadl", "cADL"),
                            ("camkes", "CAmkES"),
                            ("capdl", "CapDL"),
                            ("capnp", "Cap'n Proto"),
                            ("cbmbas", "CBM BASIC V2"),
                            ("ceylon", "Ceylon"),
                            ("cfc", "Coldfusion CFC"),
                            ("cfengine3", "CFEngine3"),
                            ("cfm", "Coldfusion HTML"),
                            ("cfs", "cfstatement"),
                            ("chai", "ChaiScript"),
                            ("chapel", "Chapel"),
                            ("charmci", "Charmci"),
                            ("cheetah", "Cheetah"),
                            ("cirru", "Cirru"),
                            ("clay", "Clay"),
                            ("clean", "Clean"),
                            ("clojure", "Clojure"),
                            ("clojurescript", "ClojureScript"),
                            ("cmake", "CMake"),
                            ("cobol", "COBOL"),
                            ("cobolfree", "COBOLFree"),
                            ("coffee-script", "CoffeeScript"),
                            ("common-lisp", "Common Lisp"),
                            ("componentpascal", "Component Pascal"),
                            ("console", "Bash Session"),
                            ("control", "Debian Control file"),
                            ("coq", "Coq"),
                            ("cpp", "C++"),
                            ("cpp-objdump", "cpp-objdump"),
                            ("cpsa", "CPSA"),
                            ("cr", "Crystal"),
                            ("crmsh", "Crmsh"),
                            ("croc", "Croc"),
                            ("cryptol", "Cryptol"),
                            ("csharp", "C#"),
                            ("csound", "Csound Orchestra"),
                            ("csound-document", "Csound Document"),
                            ("csound-score", "Csound Score"),
                            ("css", "CSS"),
                            ("css+django", "CSS+Django/Jinja"),
                            ("css+erb", "CSS+Ruby"),
                            ("css+genshitext", "CSS+Genshi Text"),
                            ("css+lasso", "CSS+Lasso"),
                            ("css+mako", "CSS+Mako"),
                            ("css+mozpreproc", "CSS+mozpreproc"),
                            ("css+myghty", "CSS+Myghty"),
                            ("css+php", "CSS+PHP"),
                            ("css+smarty", "CSS+Smarty"),
                            ("cucumber", "Gherkin"),
                            ("cuda", "CUDA"),
                            ("cypher", "Cypher"),
                            ("cython", "Cython"),
                            ("d", "D"),
                            ("d-objdump", "d-objdump"),
                            ("dart", "Dart"),
                            ("dasm16", "DASM16"),
                            ("delphi", "Delphi"),
                            ("dg", "dg"),
                            ("diff", "Diff"),
                            ("django", "Django/Jinja"),
                            ("docker", "Docker"),
                            ("doscon", "MSDOS Session"),
                            ("dpatch", "Darcs Patch"),
                            ("dtd", "DTD"),
                            ("duel", "Duel"),
                            ("dylan", "Dylan"),
                            ("dylan-console", "Dylan session"),
                            ("dylan-lid", "DylanLID"),
                            ("earl-grey", "Earl Grey"),
                            ("easytrieve", "Easytrieve"),
                            ("ebnf", "EBNF"),
                            ("ec", "eC"),
                            ("ecl", "ECL"),
                            ("eiffel", "Eiffel"),
                            ("elixir", "Elixir"),
                            ("elm", "Elm"),
                            ("emacs", "EmacsLisp"),
                            ("erb", "ERB"),
                            ("erl", "Erlang erl session"),
                            ("erlang", "Erlang"),
                            ("evoque", "Evoque"),
                            ("extempore", "xtlang"),
                            ("ezhil", "Ezhil"),
                            ("factor", "Factor"),
                            ("fan", "Fantom"),
                            ("fancy", "Fancy"),
                            ("felix", "Felix"),
                            ("fennel", "Fennel"),
                            ("fish", "Fish"),
                            ("flatline", "Flatline"),
                            ("floscript", "FloScript"),
                            ("forth", "Forth"),
                            ("fortran", "Fortran"),
                            ("fortranfixed", "FortranFixed"),
                            ("foxpro", "FoxPro"),
                            ("freefem", "Freefem"),
                            ("fsharp", "F#"),
                            ("gap", "GAP"),
                            ("gas", "GAS"),
                            ("genshi", "Genshi"),
                            ("genshitext", "Genshi Text"),
                            ("glsl", "GLSL"),
                            ("gnuplot", "Gnuplot"),
                            ("go", "Go"),
                            ("golo", "Golo"),
                            ("gooddata-cl", "GoodData-CL"),
                            ("gosu", "Gosu"),
                            ("groff", "Groff"),
                            ("groovy", "Groovy"),
                            ("gst", "Gosu Template"),
                            ("haml", "Haml"),
                            ("handlebars", "Handlebars"),
                            ("haskell", "Haskell"),
                            ("haxeml", "Hxml"),
                            ("hexdump", "Hexdump"),
                            ("hlsl", "HLSL"),
                            ("hsail", "HSAIL"),
                            ("hspec", "Hspec"),
                            ("html", "HTML"),
                            ("html+cheetah", "HTML+Cheetah"),
                            ("html+django", "HTML+Django/Jinja"),
                            ("html+evoque", "HTML+Evoque"),
                            ("html+genshi", "HTML+Genshi"),
                            ("html+handlebars", "HTML+Handlebars"),
                            ("html+lasso", "HTML+Lasso"),
                            ("html+mako", "HTML+Mako"),
                            ("html+myghty", "HTML+Myghty"),
                            ("html+ng2", "HTML + Angular2"),
                            ("html+php", "HTML+PHP"),
                            ("html+smarty", "HTML+Smarty"),
                            ("html+twig", "HTML+Twig"),
                            ("html+velocity", "HTML+Velocity"),
                            ("http", "HTTP"),
                            ("hx", "Haxe"),
                            ("hybris", "Hybris"),
                            ("hylang", "Hy"),
                            ("i6t", "Inform 6 template"),
                            ("icon", "Icon"),
                            ("idl", "IDL"),
                            ("idris", "Idris"),
                            ("iex", "Elixir iex session"),
                            ("igor", "Igor"),
                            ("inform6", "Inform 6"),
                            ("inform7", "Inform 7"),
                            ("ini", "INI"),
                            ("io", "Io"),
                            ("ioke", "Ioke"),
                            ("irc", "IRC logs"),
                            ("isabelle", "Isabelle"),
                            ("j", "J"),
                            ("jags", "JAGS"),
                            ("jasmin", "Jasmin"),
                            ("java", "Java"),
                            ("javascript+mozpreproc", "Javascript+mozpreproc"),
                            ("jcl", "JCL"),
                            ("jlcon", "Julia console"),
                            ("js", "JavaScript"),
                            ("js+cheetah", "JavaScript+Cheetah"),
                            ("js+django", "JavaScript+Django/Jinja"),
                            ("js+erb", "JavaScript+Ruby"),
                            ("js+genshitext", "JavaScript+Genshi Text"),
                            ("js+lasso", "JavaScript+Lasso"),
                            ("js+mako", "JavaScript+Mako"),
                            ("js+myghty", "JavaScript+Myghty"),
                            ("js+php", "JavaScript+PHP"),
                            ("js+smarty", "JavaScript+Smarty"),
                            ("jsgf", "JSGF"),
                            ("json", "JSON"),
                            ("json-object", "JSONBareObject"),
                            ("jsonld", "JSON-LD"),
                            ("jsp", "Java Server Page"),
                            ("julia", "Julia"),
                            ("juttle", "Juttle"),
                            ("kal", "Kal"),
                            ("kconfig", "Kconfig"),
                            ("koka", "Koka"),
                            ("kotlin", "Kotlin"),
                            ("lagda", "Literate Agda"),
                            ("lasso", "Lasso"),
                            ("lcry", "Literate Cryptol"),
                            ("lean", "Lean"),
                            ("less", "LessCss"),
                            ("lhs", "Literate Haskell"),
                            ("lidr", "Literate Idris"),
                            ("lighty", "Lighttpd configuration file"),
                            ("limbo", "Limbo"),
                            ("liquid", "liquid"),
                            ("live-script", "LiveScript"),
                            ("llvm", "LLVM"),
                            ("logos", "Logos"),
                            ("logtalk", "Logtalk"),
                            ("lsl", "LSL"),
                            ("lua", "Lua"),
                            ("make", "Makefile"),
                            ("mako", "Mako"),
                            ("maql", "MAQL"),
                            ("mask", "Mask"),
                            ("mason", "Mason"),
                            ("mathematica", "Mathematica"),
                            ("matlab", "Matlab"),
                            ("matlabsession", "Matlab session"),
                            ("md", "markdown"),
                            ("minid", "MiniD"),
                            ("modelica", "Modelica"),
                            ("modula2", "Modula-2"),
                            ("monkey", "Monkey"),
                            ("monte", "Monte"),
                            ("moocode", "MOOCode"),
                            ("moon", "MoonScript"),
                            ("mozhashpreproc", "mozhashpreproc"),
                            ("mozpercentpreproc", "mozpercentpreproc"),
                            ("mql", "MQL"),
                            ("mscgen", "Mscgen"),
                            ("mupad", "MuPAD"),
                            ("mxml", "MXML"),
                            ("myghty", "Myghty"),
                            ("mysql", "MySQL"),
                            ("nasm", "NASM"),
                            ("ncl", "NCL"),
                            ("nemerle", "Nemerle"),
                            ("nesc", "nesC"),
                            ("newlisp", "NewLisp"),
                            ("newspeak", "Newspeak"),
                            ("ng2", "Angular2"),
                            ("nginx", "Nginx configuration file"),
                            ("nim", "Nimrod"),
                            ("nit", "Nit"),
                            ("nixos", "Nix"),
                            ("nsis", "NSIS"),
                            ("numpy", "NumPy"),
                            ("nusmv", "NuSMV"),
                            ("objdump", "objdump"),
                            ("objdump-nasm", "objdump-nasm"),
                            ("objective-c", "Objective-C"),
                            ("objective-c++", "Objective-C++"),
                            ("objective-j", "Objective-J"),
                            ("ocaml", "OCaml"),
                            ("octave", "Octave"),
                            ("odin", "ODIN"),
                            ("ooc", "Ooc"),
                            ("opa", "Opa"),
                            ("openedge", "OpenEdge ABL"),
                            ("pacmanconf", "PacmanConf"),
                            ("pan", "Pan"),
                            ("parasail", "ParaSail"),
                            ("pawn", "Pawn"),
                            ("perl", "Perl"),
                            ("perl6", "Perl6"),
                            ("php", "PHP"),
                            ("pig", "Pig"),
                            ("pike", "Pike"),
                            ("pkgconfig", "PkgConfig"),
                            ("plpgsql", "PL/pgSQL"),
                            ("pony", "Pony"),
                            ("postgresql", "PostgreSQL SQL dialect"),
                            ("postscript", "PostScript"),
                            ("pot", "Gettext Catalog"),
                            ("pov", "POVRay"),
                            ("powershell", "PowerShell"),
                            ("praat", "Praat"),
                            ("prolog", "Prolog"),
                            ("properties", "Properties"),
                            ("protobuf", "Protocol Buffer"),
                            ("ps1con", "PowerShell Session"),
                            ("psql", "PostgreSQL console (psql)"),
                            ("pug", "Pug"),
                            ("puppet", "Puppet"),
                            ("py3tb", "Python 3.0 Traceback"),
                            ("pycon", "Python console session"),
                            ("pypylog", "PyPy Log"),
                            ("pytb", "Python Traceback"),
                            ("python", "Python"),
                            ("python3", "Python 3"),
                            ("qbasic", "QBasic"),
                            ("qml", "QML"),
                            ("qvto", "QVTO"),
                            ("racket", "Racket"),
                            ("ragel", "Ragel"),
                            ("ragel-c", "Ragel in C Host"),
                            ("ragel-cpp", "Ragel in CPP Host"),
                            ("ragel-d", "Ragel in D Host"),
                            ("ragel-em", "Embedded Ragel"),
                            ("ragel-java", "Ragel in Java Host"),
                            ("ragel-objc", "Ragel in Objective C Host"),
                            ("ragel-ruby", "Ragel in Ruby Host"),
                            ("raw", "Raw token data"),
                            ("rb", "Ruby"),
                            ("rbcon", "Ruby irb session"),
                            ("rconsole", "RConsole"),
                            ("rd", "Rd"),
                            ("rebol", "REBOL"),
                            ("red", "Red"),
                            ("redcode", "Redcode"),
                            ("registry", "reg"),
                            ("resource", "ResourceBundle"),
                            ("rexx", "Rexx"),
                            ("rhtml", "RHTML"),
                            ("rnc", "Relax-NG Compact"),
                            ("roboconf-graph", "Roboconf Graph"),
                            ("roboconf-instances", "Roboconf Instances"),
                            ("robotframework", "RobotFramework"),
                            ("rql", "RQL"),
                            ("rsl", "RSL"),
                            ("rst", "reStructuredText"),
                            ("rts", "TrafficScript"),
                            ("rust", "Rust"),
                            ("sarl", "SARL"),
                            ("sas", "SAS"),
                            ("sass", "Sass"),
                            ("sc", "SuperCollider"),
                            ("scala", "Scala"),
                            ("scaml", "Scaml"),
                            ("scheme", "Scheme"),
                            ("scilab", "Scilab"),
                            ("scss", "SCSS"),
                            ("sgf", "SmartGameFormat"),
                            ("shen", "Shen"),
                            ("silver", "Silver"),
                            ("slash", "Slash"),
                            ("slim", "Slim"),
                            ("slurm", "Slurm"),
                            ("smali", "Smali"),
                            ("smalltalk", "Smalltalk"),
                            ("smarty", "Smarty"),
                            ("sml", "Standard ML"),
                            ("snobol", "Snobol"),
                            ("snowball", "Snowball"),
                            ("sourceslist", "Debian Sourcelist"),
                            ("sp", "SourcePawn"),
                            ("sparql", "SPARQL"),
                            ("spec", "RPMSpec"),
                            ("splus", "S"),
                            ("sql", "SQL"),
                            ("sqlite3", "sqlite3con"),
                            ("squidconf", "SquidConf"),
                            ("ssp", "Scalate Server Page"),
                            ("stan", "Stan"),
                            ("stata", "Stata"),
                            ("swift", "Swift"),
                            ("swig", "SWIG"),
                            ("systemverilog", "systemverilog"),
                            ("tads3", "TADS 3"),
                            ("tap", "TAP"),
                            ("tasm", "TASM"),
                            ("tcl", "Tcl"),
                            ("tcsh", "Tcsh"),
                            ("tcshcon", "Tcsh Session"),
                            ("tea", "Tea"),
                            ("termcap", "Termcap"),
                            ("terminfo", "Terminfo"),
                            ("terraform", "Terraform"),
                            ("tex", "TeX"),
                            ("text", "Text only"),
                            ("thrift", "Thrift"),
                            ("todotxt", "Todotxt"),
                            ("toml", "TOML"),
                            ("trac-wiki", "MoinMoin/Trac Wiki markup"),
                            ("treetop", "Treetop"),
                            ("ts", "TypeScript"),
                            ("tsql", "Transact-SQL"),
                            ("ttl", "Tera Term macro"),
                            ("turtle", "Turtle"),
                            ("twig", "Twig"),
                            ("typoscript", "TypoScript"),
                            ("typoscriptcssdata", "TypoScriptCssData"),
                            ("typoscripthtmldata", "TypoScriptHtmlData"),
                            ("ucode", "ucode"),
                            ("unicon", "Unicon"),
                            ("urbiscript", "UrbiScript"),
                            ("vala", "Vala"),
                            ("vb.net", "VB.net"),
                            ("vbscript", "VBScript"),
                            ("vcl", "VCL"),
                            ("vclsnippets", "VCLSnippets"),
                            ("vctreestatus", "VCTreeStatus"),
                            ("velocity", "Velocity"),
                            ("verilog", "verilog"),
                            ("vgl", "VGL"),
                            ("vhdl", "vhdl"),
                            ("vim", "VimL"),
                            ("wdiff", "WDiff"),
                            ("whiley", "Whiley"),
                            ("x10", "X10"),
                            ("xml", "XML"),
                            ("xml+cheetah", "XML+Cheetah"),
                            ("xml+django", "XML+Django/Jinja"),
                            ("xml+erb", "XML+Ruby"),
                            ("xml+evoque", "XML+Evoque"),
                            ("xml+lasso", "XML+Lasso"),
                            ("xml+mako", "XML+Mako"),
                            ("xml+myghty", "XML+Myghty"),
                            ("xml+php", "XML+PHP"),
                            ("xml+smarty", "XML+Smarty"),
                            ("xml+velocity", "XML+Velocity"),
                            ("xorg.conf", "Xorg"),
                            ("xquery", "XQuery"),
                            ("xslt", "XSLT"),
                            ("xtend", "Xtend"),
                            ("xul+mozpreproc", "XUL+mozpreproc"),
                            ("yaml", "YAML"),
                            ("yaml+jinja", "YAML+Jinja"),
                            ("zephir", "Zephir"),
                        ],
                        default="python",
                        max_length=100,
                    ),
                ),
                (
                    "style",
                    models.CharField(
                        choices=[
                            ("abap", "abap"),
                            ("algol", "algol"),
                            ("algol_nu", "algol_nu"),
                            ("arduino", "arduino"),
                            ("autumn", "autumn"),
                            ("borland", "borland"),
                            ("bw", "bw"),
                            ("colorful", "colorful"),
                            ("default", "default"),
                            ("emacs", "emacs"),
                            ("friendly", "friendly"),
                            ("fruity", "fruity"),
                            ("igor", "igor"),
                            ("lovelace", "lovelace"),
                            ("manni", "manni"),
                            ("monokai", "monokai"),
                            ("murphy", "murphy"),
                            ("native", "native"),
                            ("paraiso-dark", "paraiso-dark"),
                            ("paraiso-light", "paraiso-light"),
                            ("pastie", "pastie"),
                            ("perldoc", "perldoc"),
                            ("rainbow_dash", "rainbow_dash"),
                            ("rrt", "rrt"),
                            ("sas", "sas"),
                            ("solarized-dark", "solarized-dark"),
                            ("solarized-light", "solarized-light"),
                            ("stata", "stata"),
                            ("stata-dark", "stata-dark"),
                            ("stata-light", "stata-light"),
                            ("tango", "tango"),
                            ("trac", "trac"),
                            ("vim", "vim"),
                            ("vs", "vs"),
                            ("xcode", "xcode"),
                        ],
                        default="friendly",
                        max_length=100,
                    ),
                ),
                ("highlighted", models.TextField()),
                (
                    "owner",
                    models.ForeignKey(
                        on_delete=django.db.models.deletion.CASCADE,
                        related_name="snippets",
                        to=settings.AUTH_USER_MODEL,
                    ),
                ),
            ],
            options={"ordering": ("created",)},
        )
    ]



from django.contrib.auth import authenticate
from django.views.decorators.csrf import csrf_exempt
from rest_framework.authtoken.models import Token
from rest_framework.decorators import api_view, permission_classes
from rest_framework.permissions import AllowAny
from rest_framework.status import (
    HTTP_400_BAD_REQUEST,
    HTTP_404_NOT_FOUND,
    HTTP_200_OK
)
from rest_framework.response import Response


@csrf_exempt
@api_view(["POST"])
@permission_classes((AllowAny,))
def login(request):
    username = request.data.get("username")
    password = request.data.get("password")
    if username is None or password is None:
        return Response({'error': 'Please provide both username and password'},
                        status=HTTP_400_BAD_REQUEST)
    user = authenticate(username=username, password=password)
    if not user:
        return Response({'error': 'Invalid Credentials'},
                        status=HTTP_404_NOT_FOUND)
    token, _ = Token.objects.get_or_create(user=user)
    return Response({'token': token.key},
                    status=HTTP_200_OK)


@csrf_exempt
@api_view(["GET"])
def sample_api(request):
    data = {'sample_data': 'curtis'}
    return Response(data, status=HTTP_200_OK)



from django.db import models

from pygments.lexers import get_all_lexers
from pygments.styles import get_all_styles
from pygments.lexers import get_lexer_by_name
from pygments.formatters.html import HtmlFormatter
from pygments import highlight

# Create your models here.

LEXERS = [item for item in get_all_lexers() if item[1]]
LANGUAGE_CHOICES = sorted([(item[1][0], item[0]) for item in LEXERS])
STYLE_CHOICES = sorted((item, item) for item in get_all_styles())


class Snippet(models.Model):
    created = models.DateTimeField(auto_now_add=True)
    title = models.CharField(max_length=100, blank=True, default="")
    code = models.TextField()
    linenos = models.BooleanField(default=False)
    language = models.CharField(
        choices=LANGUAGE_CHOICES, default="python", max_length=100
    )
    style = models.CharField(choices=STYLE_CHOICES, default="friendly", max_length=100)
    owner = models.ForeignKey(
        "auth.User", related_name="snippets", on_delete=models.CASCADE
    )
    highlighted = models.TextField()

    class Meta:
        ordering = ("created",)

    def save(self, *args, **kwargs):
        lexer = get_lexer_by_name(self.language)
        linenos = "table" if self.linenos else False
        options = {"title": self.title} if self.title else {}
        formatter = HtmlFormatter(
            style=self.style, linenos=linenos, full=True, **options
        )
        self.highlighted = highlight(self.code, lexer, formatter)
        super(Snippet, self).save(*args, **kwargs)



from django.db import models

# Create your models here.


class Project(models.Model):
    title = models.CharField(max_length=100)
    describe = models.CharField(max_length=30)
    technology = models.TextField()



from __future__ import absolute_import
import os
from celery import Celery
from django.conf import settings

# set the default Django settings module for the 'celery' program.
os.environ.setdefault('DJANGO_SETTINGS_MODULE', 'curtisproject.settings')
app = Celery('curtisproject')

# Using a string here means the worker will not have to
# pickle the object when using Windows.
app.config_from_object('django.conf:settings')
app.autodiscover_tasks(lambda: settings.INSTALLED_APPS)


@app.task(bind=True)
def debug_task(self):
    print('Request: {0!r}'.format(self.request))



from django.views.generic.edit import FormView
from feedback.forms import FeedbackForm


class FeedbackView(FormView):
    template_name = 'feedback/contact.html'
    form_class = FeedbackForm
    success_url = '/'

    def form_valid(self, form):
        form.send_email()
        return super(FeedbackView, self).form_valid(form)



"""
Django settings for curtisproject project.

Generated by 'django-admin startproject' using Django 2.2.3.

For more information on this file, see
https://docs.djangoproject.com/en/2.2/topics/settings/

For the full list of settings and their values, see
https://docs.djangoproject.com/en/2.2/ref/settings/
"""

import os
import sentry_sdk
from sentry_sdk.integrations.django import DjangoIntegration

sentry_sdk.init(
    dsn="https://afee056ab8b84c46b18d61accb4b67db@sentry.io/1520038",
    integrations=[DjangoIntegration()]
)

# Build paths inside the project like this: os.path.join(BASE_DIR, ...)
BASE_DIR = os.path.dirname(os.path.dirname(os.path.abspath(__file__)))


# Quick-start development settings - unsuitable for production
# See https://docs.djangoproject.com/en/2.2/howto/deployment/checklist/

# SECURITY WARNING: keep the secret key used in production secret!
SECRET_KEY = 'g@s41!!i(-2#f3tg1uk+$$c!dsr+)1)=+6a^_jrkq^+tcmthbo'

# SECURITY WARNING: don't run with debug turned on in production!
DEBUG = True

ALLOWED_HOSTS = ['*']


# Application definition

INSTALLED_APPS = [
    'django.contrib.admin',
    'django.contrib.auth',
    'django.contrib.contenttypes',
    'django.contrib.sessions',
    'django.contrib.messages',
    'django.contrib.staticfiles',
    'hello',
    'django_prometheus',
    'feedback',
    'photos',
    'rest_framework',
    'snippets',
    'rest_framework.authtoken',
    'django.contrib.sites',
    'allauth',
    'allauth.account',
    'allauth.socialaccount',
    'allauth.socialaccount.providers.google',
]

MIDDLEWARE = [
    'django.middleware.security.SecurityMiddleware',
    'django.contrib.sessions.middleware.SessionMiddleware',
    'django.middleware.common.CommonMiddleware',
    'django.middleware.csrf.CsrfViewMiddleware',
    'django.contrib.auth.middleware.AuthenticationMiddleware',
    'django.contrib.messages.middleware.MessageMiddleware',
    'django.middleware.clickjacking.XFrameOptionsMiddleware',
]

ROOT_URLCONF = 'curtisproject.urls'

TEMPLATES = [
    {
        'BACKEND': 'django.template.backends.django.DjangoTemplates',
        'DIRS': [os.path.join(BASE_DIR, 'hello/templates')],
        'APP_DIRS': True,
        'OPTIONS': {
            'context_processors': [
                'django.template.context_processors.debug',
                'django.template.context_processors.request',
                'django.contrib.auth.context_processors.auth',
                'django.contrib.messages.context_processors.messages',
            ],
        },
    },
]

WSGI_APPLICATION = 'curtisproject.wsgi.application'


# Database
# https://docs.djangoproject.com/en/2.2/ref/settings/#databases

DATABASES = {
    'default': {
        'ENGINE': 'django.db.backends.sqlite3',
        'NAME': os.path.join(BASE_DIR, 'db.sqlite3'),
    }
}

# DATABASES = {
#     "default": {
#         "ENGINE": "django.db.backends.postgresql_psycopg2",
#         "NAME": "coffee",
#         "USER": "curtisproject",
#         "PASSWORD": "last",
#         # "HOST": "db",
#         "PORT": "5432",
#     }
# }

# Password validation
# https://docs.djangoproject.com/en/2.2/ref/settings/#auth-password-validators

AUTH_PASSWORD_VALIDATORS = [
    {
        'NAME': 'django.contrib.auth.password_validation.UserAttributeSimilarityValidator',
    },
    {
        'NAME': 'django.contrib.auth.password_validation.MinimumLengthValidator',
    },
    {
        'NAME': 'django.contrib.auth.password_validation.CommonPasswordValidator',
    },
    {
        'NAME': 'django.contrib.auth.password_validation.NumericPasswordValidator',
    },
]


# Internationalization
# https://docs.djangoproject.com/en/2.2/topics/i18n/

LANGUAGE_CODE = 'en-us'

TIME_ZONE = 'UTC'

USE_I18N = True

USE_L10N = True

USE_TZ = True


# Static files (CSS, JavaScript, Images)
# https://docs.djangoproject.com/en/2.2/howto/static-files/

STATIC_URL = '/static/'
STATIC_ROOT = os.path.join(BASE_DIR, 'static/')

# CELERY
BROKER_URL = 'redis://localhost:6379'
CELERY_RESULT_BACKEND = 'redis://localhost:6379'
CELERY_ACCEPT_CONTENT = ['application/json']
CELERY_TASK_SERIALIZER = 'json'
CELERY_RESULT_SERIALIZER = 'json'
CELERY_TIMEZONE = 'Africa/Nairobi'

# Emails
EMAIL_BACKEND = 'django.core.mail.backends.console.EmailBackend'
EMAIL_HOST = 'localhost'
EMAIL_PORT = 1025
DEFAULT_FROM_EMAIL = 'Picha <cuttice@example.com>'


PROMETHEUS_EXPORT_MIGRATIONS = False

REST_FRAMEWORK = {
    'DEFAULT_AUTHENTICATION_CLASSES': (
        'rest_framework.authentication.TokenAuthentication',
    ),
    'DEFAULT_PERMISSION_CLASSES': (
        'rest_framework.permissions.IsAuthenticated', )
}
AUTHENTICATION_BACKENDS = (
    'django.contrib.auth.backends.ModelBackend',

    'allauth.account.auth_backends.AuthenticationBackend',
)

SITE_ID = 1
LOGIN_REDIRECT_URL = '/'


from django.test import SimpleTestCase
from hello.forms import ProjectForm
import pytest
from django.contrib.admin.sites import AdminSite
from mixer.backend.django import mixer
from hello import admin
from hello import models
from django.urls import reverse, resolve
from hello.views import project_create_view, project_views
from django.test import TestCase, Client
from hello.models import Project
from django.urls import reverse
import json


pytestmark = pytest.mark.django_db


class TestViews(TestCase):
    def test_create_list_GET(self):
        client = Client()
        response = client.get(reverse("create"))
        self.assertEqual(response.status_code, 200)
        self.assertTemplateUsed(response, "project/project_create.html")
       
    def test_project_views_GET(self):
        client = Client()
        response = client.get(reverse("project"))
        self.assertEqual(response.status_code, 200)

class TestUrls(SimpleTestCase):
    def test_create_url_is_resolved(self):
        url = reverse("create")
        self.assertEqual(resolve(url).func, project_create_view)

    def test_project_url_is_resolved(self):
        url = reverse("project")
        self.assertEqual(resolve(url).func, project_views)


def test_an_admin_view(admin_client):
    response = admin_client.get('/admin/')
    assert response.status_code == 200
class TestProjectAdmin:
	def test_expect(self):
		 site = AdminSite()


class TestForms(SimpleTestCase):
    def test_project_form_valid(self):
        form = ProjectForm(
            data={"title": "capuchino", "describe": "hot", "technology": "really hot"}
        )
        self.assertTrue(form.is_valid())

    def test_project_form_no_data(self):
        form = ProjectForm(data={})
        self.assertFalse(form.is_valid())
        self.assertTrue(len(form.errors), 3)



from snippets.models import Snippet
from snippets.serializers import SnippetSerializer
from rest_framework import generics
from django.contrib.auth.models import User
from snippets.serializers import UserSerializer
from rest_framework import permissions
from django.shortcuts import render
from django.http import HttpResponse


class SnippetList(generics.ListCreateAPIView):
    queryset = Snippet.objects.all()
    serializer_class = SnippetSerializer
    permission_classes = (permissions.IsAuthenticatedOrReadOnly,)

    def perform_create(self, serializer):
        serializer.save(owner=self.request.user)


class SnippetDetail(generics.RetrieveUpdateDestroyAPIView):
    queryset = Snippet.objects.all()
    serializer_class = SnippetSerializer
    permission_classes = (permissions.IsAuthenticatedOrReadOnly,)


class UserList(generics.ListAPIView):
    queryset = User.objects.all()
    serializer_class = UserSerializer


class UserDetail(generics.RetrieveAPIView):
    queryset = User.objects.all()
    serializer_class = UserSerializer



from django.views.generic.list import ListView

from photos.models import Photo
from feedback.forms import FeedbackForm


class PhotoView(ListView):
    model = Photo
    template_name = 'photos/photo_list.html'
    paginate_by = 24

    def get_context_data(self, **kwargs):
        context = super(PhotoView, self).get_context_data(**kwargs)
        context['form'] = FeedbackForm()
        return context



from django.urls import path
from rest_framework.urlpatterns import format_suffix_patterns
from snippets import views

urlpatterns = [
    path("snippets/", views.SnippetList.as_view()),
    path("snippets/<int:pk>/", views.SnippetDetail.as_view()),
    path("users/", views.UserList.as_view()),
    path("users/<int:pk>/", views.UserDetail.as_view()),
]

urlpatterns = format_suffix_patterns(urlpatterns)



from django.conf import settings
from django.core.mail import EmailMessage
from django.template import Context
from django.template.loader import render_to_string


def send_feedback_email(email, message):
    c = Context({'email': email, 'message': message})

    email_subject = render_to_string(
        'feedback/email/feedback_email_subject.txt', c).replace('\n', '')
    email_body = render_to_string('feedback/email/feedback_email_body.txt', c)

    email = EmailMessage(
        email_subject, email_body, email,
        [settings.DEFAULT_FROM_EMAIL], [],
        headers={'Reply-To': email}
    )
    return email.send(fail_silently=False)



import pytest

from hello.models import Project

pytestmark = pytest.mark.django_db


class TestProjectModel:

    def test_save():
        product = Project.objects.create(
            title='Sample',
            describe='team',
            technology='goood'
        )
        assert product.title == Sample
        assert product.describe == team
        assert product.technology == goood



from django.test import TestCase, Client
from hello.models import Project
from django.urls import reverse
import json
import pytest

class TestViews(TestCase):
    def test_create_list_GET(self):
        client = Client()
        response = client.get(reverse("create"))
        self.assertEqual(response.status_code, 200)
        self.assertTemplateUsed(response, "project/project_create.html")
       
    def test_project_views_GET(self):
        client = Client()
        response = client.get(reverse("project"))
        self.assertEqual(response.status_code, 200)

   


"""
WSGI config for curtisproject project.

It exposes the WSGI callable as a module-level variable named ``application``.

For more information on this file, see
https://docs.djangoproject.com/en/2.2/howto/deployment/wsgi/
"""

import os

from django.core.wsgi import get_wsgi_application

os.environ.setdefault('DJANGO_SETTINGS_MODULE', 'curtisproject.settings')

application = get_wsgi_application()



from celery.decorators import task
from celery.utils.log import get_task_logger

from feedback.emails import send_feedback_email

logger = get_task_logger(__name__)


@task(name="send_feedback_email_task")
def send_feedback_email_task(email, message):
    """sends an email when feedback form is filled successfully"""
    logger.info("Sent feedback email")
    return send_feedback_email(email, message)



from django.db import models


class Photo(models.Model):
    created_on = models.DateTimeField("Created on", auto_now_add=True)
    updated_on = models.DateTimeField("Updated on", auto_now=True)
    title = models.CharField("Title", max_length=255)
    link = models.URLField(
        "Photo Link", max_length=255, help_text="The URL to the image page")
    image_url = models.URLField(
        "Image URL", max_length=255, help_text="The URL to the image file itself")
    description = models.TextField("Description")

    class Meta:
        verbose_name = "Photo"
        verbose_name_plural = "Photos"
        ordering = ['-created_on', 'title']

    def __str__(self):
        return self.title
